@@ -64,9 +64,13 @@ if os.name == 'nt':
     del libintl
 else:
     locale.bindtextdomain(DOMAIN, localedir)
+    try:
+        locale.bind_textdomain_codeset(DOMAIN, 'UTF-8')
+    except AttributeError:
+        pass
 
 APPNAME = 'PDF Arranger'
-VERSION = '1.2.0'
+VERSION = '1.2.1'
 WEBSITE = 'https://github.com/jeromerobert/pdfarranger'
 LICENSE = 'GNU General Public License (GPL) Version 3.'
 
@@ -728,8 +732,10 @@ class PdfArranger(Gtk.Application):
                 current_page.mediaBox.upperRight = (x2_new, y2_new)
 
             pdf_output.addPage(current_page)
-
-        pdf_output.addMetadata(metadata)
+        if metadata is not None:
+            metadata = {k: v for k, v in metadata.items()
+                if isinstance(v, (str, bytes))}
+            pdf_output.addMetadata(metadata)
         # finally, write "output" to document-output.pdf
         pdf_output.write(open(file_out, 'wb'))
 
